@@ -36,6 +36,12 @@ from twisted.internet import defer
 from zope.interface import implements
 
 from ubuntuone.storageprotocol import protocol_pb2, validators
+from ubuntuone.storageprotocol.errors import (
+    StorageProtocolError, StorageProtocolErrorSizeTooBig,
+    StorageProtocolProtocolError, StorageRequestError,
+    RequestCancelledError, error_to_exception
+)
+
 
 # the max possible packet size is 2**32 (32 bits for size)
 # although we will not allow packets that big for now
@@ -53,40 +59,6 @@ MAX_PAYLOAD_SIZE = MAX_MESSAGE_SIZE-300
 # the referred is the own root node, and not any of the shares
 ROOT = ''
 
-class StorageProtocolError(Exception):
-    """base class for all client/server exceptions."""
-
-class StorageProtocolErrorSizeTooBig(StorageProtocolError):
-    """the size we received was too big."""
-
-class StorageProtocolProtocolError(StorageProtocolError):
-    """A protocol error on the storage protocol."""
-
-
-class StorageRequestError(StorageProtocolError):
-    """an exception that keeps the request that generated it around
-
-    """
-    def __init__(self, request, message):
-        """create a StorageRequestError.
-
-        @param request: the request that generated this error.
-        @param message: the message received that generated the error.
-        """
-        error_name = protocol_pb2.Error.DESCRIPTOR \
-                 .enum_types_by_name['ErrorType'] \
-                 .values_by_number[message.error.type].name
-        super(StorageRequestError, self).__init__(error_name)
-        #: the request that generated the error
-        self.request = request
-        #: the message received that generated the error
-        self.error_message = message
-
-
-class RequestCancelledError(Exception):
-    """The request is cancelled."""
-
-
 class RequestHandler(Protocol):
     """the base class for a network peer.
 
@@ -418,6 +390,14 @@ class Request(object):
         """override this method to start the request."""
         raise NotImplementedError("request needs to do something")
 
+    def _default_process_message(self, message):
+        """Map ERROR message to a specific exception."""
+        if message.type == protocol_pb2.Message.ERROR:
+            error_class = error_to_exception(message.error.type)
+        else:
+            error_class = StorageRequestError
+        self.error(error_class(self, message))
+
     def processMessage(self, message):
         """handle an incoming message for this request. override this.
 
